CustomSingleSearchSelectView<T> class

Inheritance
Mixed-in types

Constructors

CustomSingleSearchSelectView({Key? key, required List<T> items, required String title, required FormFieldState<T>? state, double? width, double? height, required void onSelect(dynamic value), InputDecoration? decoration, InputDecoration? searchDecoration, T? initialValue, Color selectedItemColor = Colors.redAccent, String? cancelText, Color? cancelBackgroundColor, TextStyle? cancelTextStyle, TextStyle? titleTextStyle, Color? itemBackgroundColor, Color? titleBackgroundColor, Color? separatorColor, double? separatorHeight, TextStyle? itemTextStyle, TextStyle? searchStyle, bool isBarrierDismissible = true, TextStyle? selectedItemTextStyle})

Properties

cancelBackgroundColor → Color?
final
cancelText → String?
final
cancelTextStyle → TextStyle?
final
decoration → InputDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
initialValue → T?
final
isBarrierDismissible → bool
final
itemBackgroundColor → Color?
final
items → List<T>
final
itemTextStyle → TextStyle?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelect → void Function(dynamic value)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchDecoration → InputDecoration?
final
searchStyle → TextStyle?
final
selectedItemColor → Color
final
selectedItemTextStyle → TextStyle?
final
separatorColor → Color?
final
separatorHeight → double?
final
state → FormFieldState<T>?
final
title → String
final
titleBackgroundColor → Color?
final
titleTextStyle → TextStyle?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomSingleSearchSelectView>
Creates the mutable state for this widget at a given location in the tree.
override
customBottomSheet({required BuildContext buildContext, required String headerName, TextStyle? headerNameTextStyle, Color? headerNameBackgroundColor, required List<CustomSelectItem<T>> dropdownItems, T? initialSelection, Color? selectedItemColor, TextStyle? selectedItemTextStyle, bool isBarrierDismissible = true, String cancelText = "Cancel", Color? separatorColor, double separatorHeight = 1, Color? cancelBackgroundColor, Color? dropdownItemBackgroundColor, TextStyle? cancelTextStyle, TextStyle? itemTextStyle}) → Future<T?>
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited